@@ -5,7 +5,7 @@ operators describe transformations that are subsets of those possible by the suc
 # Author: Alex Safatli
 # E-mail: safatli@cs.dal.ca
 
-import newick
+import newick, tree
 from bipartition import bipartition
 
 # Exception Handling
@@ -81,10 +81,9 @@ class rearrangement:
     
     def toTree(self):
         
-        ''' Commit the move and transform to
-        tree object. '''
+        ''' Commit the move and transform to tree object. '''
         
-        out = newick.tree(self.toNewick())
+        out = tree.tree(self.toNewick())
         out.origin = self.getType()
         return out
     
@@ -93,7 +92,7 @@ class rearrangement:
     def __str__(self):
         
         t = self.getType()
-        return '<%s> move [%s] to [%s]' %  (t,self.target,self.destination)
+        return '<%s> move [%s] to [%s]' % (t,self.target,self.destination)
 
 # Tree structure.
 
@@ -140,7 +139,7 @@ class topology:
         for br in self.branches:
             # Anything inside the subtree for that branch
             # is forbidden to be moved to by this branch.
-            self.forbidden[br] = newick.getAllBranches(br)
+            self.forbidden[br] = [_ for _ in newick.getAllBranches(br)]
             # Any siblings are also forbidden 
             # (give the same tree).
             siblings = br.parent.children
@@ -611,14 +610,14 @@ class topology:
         
         ''' Return the tree object for this topology. '''
         
-        return newick.tree(self.toNewick())
+        return tree.tree(self.toNewick())
         
     def toUnrootedTree(self):
         
         ''' Return the tree object of the unrooted 
         version of this topology. '''
         
-        return newick.tree(self.toUnrootedNewick())
+        return tree.tree(self.toUnrootedNewick())
         
     def __str__(self):
         
